==> react-device-frame-2.0.5.tgz: package/src/device.js <==
import React, { Component } from "react";
import PropTypes from "prop-types";
import  iphonex from "./iphonex";
import  iphone8 from "./iphone8";
import  iphone8plus from "./iphone8plus";
import  iphone5s from "./iphone5s";
import  iphone5c from "./iphone5c";
import  iphone4s from "./iphone4s";
import  ipad from "./ipad";
import  macbookpro from "./macbookpro";
import  nexus5 from "./nexus5";
import  galaxys5 from "./galaxys5";
import  galaxynote8 from "./galaxynote8";
import  htcone from "./htcone";
import  lumia920 from "./lumia920";

export default class Device extends Component {


  getDevice(type)
  {
    let device ;
    const iphonex = (<iphonex
      color={this.props.color}
      site={this.props.url}
    />);
    const iphone8 = (<iphone8
      color={this.props.color}
      site={this.props.url}
                     />);
    const iphone8plus = (<iphone8plus
      color={this.props.color}
      site={this.props.url}
                         />);
    const iphone5s = (<iphone5s
      color={this.props.color}
      site={this.props.url}
                      />);
    const iphone5c = (<iphone5c
      color={this.props.color}
      site={this.props.url}
                      />);
    const iphone4s = (<iphone4s
      color={this.props.color}
      site={this.props.url}
                      />);
    const ipad = (<ipad
      color={this.props.color}
      site={this.props.url}
                  />);
    const macbookpro = (<macbookpro
      color={this.props.color}
      site={this.props.url}
                        />);
    const nexus5 = (<nexus5
      color={this.props.color}
      site={this.props.url}
                    />);
    const galaxys5 = (<galaxys5
      color={this.props.color}
      site={this.props.url}
                      />);
    const galaxynote8 = (<galaxynote8
      color={this.props.color}
      site={this.props.url}
                         />);

    if (type === "iphone-x")
    {
      return iphonex;
    } else if (type === "iphone-8") {
      return iphone8;
    } else if (type === "iphone-8plus")
    {
      return iphone8plus;
    } else if (type === "iphone-5s"){
      return iphone5s;
    } else if (type === "iphone-5c"){
      return iphone5c;
    } else if (type === "iphone-4s"){
      return iphone4s;
    } else if (type === "ipad-mini"){
      return ipad;
    } else if (type === "macbook-pro"){
      return macbookpro;
    } else if (type === "htc-one"){
      return htcone;
    } else if (type === "nexus-5"){
      return nexus5;
    } else if (type === "galaxy-s5"){
      return galaxys5;
    } else if (type === "galaxy-note8"){
      return galaxynote8;
    }
  }

  render() {

    const device = this.getDevice(this.props.name);

    return device;
  }
}

Device.propTypes = {
  name: PropTypes.string.isRequired,
  color: PropTypes.string,
  url: PropTypes.string
};

==> react-device-frame-2.0.6.tgz: package/src/device.js <==
import React, { Component } from "react";
import PropTypes from "prop-types";
import  iphonex from "./iphonex";
import  Iphone8 from "./iphone8";
import  iphone8plus from "./iphone8plus";
import  iphone5s from "./iphone5s";
import  iphone5c from "./iphone5c";
import  iphone4s from "./iphone4s";
import  ipad from "./ipad";
import  macbookpro from "./macbookpro";
import  nexus5 from "./nexus5";
import  galaxys5 from "./galaxys5";
import  galaxynote8 from "./galaxynote8";
import  htcone from "./htcone";
import  lumia920 from "./lumia920";

export default class Device extends Component {


  getDevice(type)
  {
    let device ;
    const iphonex = (<iphonex
      color={this.props.color}
      site={this.props.url}
    />);
    const iphone8 = (<Iphone8
      color={this.props.color}
      site={this.props.url}
    />);
    const iphone8plus = (<iphone8plus
      color={this.props.color}
      site={this.props.url}
                         />);
    const iphone5s = (<iphone5s
      color={this.props.color}
      site={this.props.url}
                      />);
    const iphone5c = (<iphone5c
      color={this.props.color}
      site={this.props.url}
                      />);
    const iphone4s = (<iphone4s
      color={this.props.color}
      site={this.props.url}
                      />);
    const ipad = (<ipad
      color={this.props.color}
      site={this.props.url}
                  />);
    const macbookpro = (<macbookpro
      color={this.props.color}
      site={this.props.url}
                        />);
    const nexus5 = (<nexus5
      color={this.props.color}
      site={this.props.url}
                    />);
    const galaxys5 = (<galaxys5
      color={this.props.color}
      site={this.props.url}
                      />);
    const galaxynote8 = (<galaxynote8
      color={this.props.color}
      site={this.props.url}
                         />);

    if (type === "iphone-x")
    {
      return iphonex;
    } else if (type === "iphone-8") {
      return iphone8;
    } else if (type === "iphone-8plus")
    {
      return iphone8plus;
    } else if (type === "iphone-5s"){
      return iphone5s;
    } else if (type === "iphone-5c"){
      return iphone5c;
    } else if (type === "iphone-4s"){
      return iphone4s;
    } else if (type === "ipad-mini"){
      return ipad;
    } else if (type === "macbook-pro"){
      return macbookpro;
    } else if (type === "htc-one"){
      return htcone;
    } else if (type === "nexus-5"){
      return nexus5;
    } else if (type === "galaxy-s5"){
      return galaxys5;
    } else if (type === "galaxy-note8"){
      return galaxynote8;
    }
  }

  render() {

    const device = this.getDevice(this.props.name);

    return device;
  }
}

Device.propTypes = {
  name: PropTypes.string.isRequired,
  color: PropTypes.string,
  url: PropTypes.string
};
